@@ -21,6 +21,9 @@
 #include "plugininterface.h"
 
 #include <QtCore/QMutexLocker>
+#include <qdvdinfo.h>
+
+const int KMF::MediaObject::constIconSize = 96;
 
 KMF::MediaObject::MediaObject(QObject *parent)
     : Object(parent)
@@ -40,7 +43,7 @@ KMF::TemplateObject::~TemplateObject()
 {
 }
 
-QImage KMF::TemplateObject::preview(const QString &)
+QImage KMF::TemplateObject::preview(const QString &, int, int)
 {
     return QImage();
 }
@@ -50,6 +53,11 @@ QStringList KMF::TemplateObject::menus()
     return QStringList();
 }
 
+int KMF::TemplateObject::chaptersPerPage(const QString &)
+{
+    return 0;
+}
+
 bool KMF::TemplateObject::clicked()
 {
     return false;
@@ -81,6 +89,11 @@ KMF::PluginInterface::~PluginInterface()
 {
 }
 
+uint KMF::PluginInterface::aspectRatio() const
+{
+     return QDVD::VideoTrack::Aspect_4_3;
+}
+
 static QMutex mutex;
 static QMap<uint, uint> parents;
 static uint id = 0;
