@@ -28,7 +28,6 @@
 
 #include <stdint.h>
 
-#include <qdvdinfo.h>
 #include "job.h"
 #include "object.h"
 
@@ -61,7 +60,7 @@ class KDE_EXPORT MediaObject : public Object
         }
 
     public:
-        static const int constIconSize = 96;
+        static const int constIconSize;
 };
 
 class KDE_EXPORT OutputObject : public Object
@@ -71,6 +70,8 @@ class KDE_EXPORT OutputObject : public Object
     public:
         explicit OutputObject(QObject *parent);
         ~OutputObject();
+        
+        virtual bool isValid() const { return true; }
 };
 
 class KDE_EXPORT TemplateObject : public Object
@@ -83,10 +84,14 @@ class KDE_EXPORT TemplateObject : public Object
 
         virtual bool clicked();
         virtual QStringList menus();
+        virtual int chaptersPerPage(const QString &page);
 
     public slots:
         // Help Kross plugin declaring these as slots
-        virtual QImage preview(const QString & = "");
+        virtual QImage preview(const QString &page=QString(), int title=0, int chapter=0);
+        
+    Q_SIGNALS:
+        void updated();
 };
 
 class KDE_EXPORT ProgressDialog : public QObject
@@ -128,10 +133,7 @@ class KDE_EXPORT PluginInterface : public QObject
         virtual QDateTime lastModified(DirtyType type) = 0;
         virtual int serial() = 0;
         virtual bool addMediaAction(QAction *action, const QString &group = "") const = 0;
-        virtual QDVD::VideoTrack::AspectRatio aspectRatio() const
-        {
-            return QDVD::VideoTrack::Aspect_4_3;
-        }
+        virtual uint aspectRatio() const;
 
         virtual bool addMediaObject(MediaObject *media) const = 0;
         virtual bool addTemplateObject(TemplateObject *tob) = 0;
@@ -145,6 +147,7 @@ class KDE_EXPORT PluginInterface : public QObject
 
         virtual void addJob(KMF::Job *job, JobDependency dependency = KMF::None) = 0;
         virtual void addJob(KMF::Job *job, KMF::Job *dependency) = 0;
+        virtual bool executableJobsRemaining() = 0;
 
         static uint messageId();
         virtual void message(uint id, MsgType type, const QString &msg = QString()) = 0;
