@@ -26,7 +26,7 @@
 #include <KDebug>
 
 #include "kmftime.h"
-#include "run.h"
+#include "videofile.h"
 
 QMap<QString, KMFMediaFile> KMFMediaFile::m_cache;
 
@@ -39,51 +39,42 @@ KMFMediaFile::KMFMediaFile(const QString &file)
     }
 }
 
+bool checkRatio(double orig, double ratio)
+{
+    // Checlk returned ratio nis with +/- 1% of desired ratio...
+    return orig>(ratio*0.99) && orig<(ratio*1.01);
+}
+
 bool KMFMediaFile::probe()
 {
-    Run run(QString("kmf_info \"%1\"").arg(m_file));
-
-    if (run.exitStatus() == 0) {
-        QStringList lines = run.output().split('\n');
-        QMap<QString, QString> info;
-
-        for (QStringList::Iterator it = lines.begin(); it != lines.end(); ++it) {
-            QStringList keyAndValue = it->split('=');
-
-            if (keyAndValue.count() == 2) {
-                info[keyAndValue[0]] = keyAndValue[1];
-            }
+    VideoFile video;
+    if(video.open(m_file)) {
+        double ratio=video.getAspect();
+        if (checkRatio(ratio, 16.0/9.0)) {
+            m_aspectRatio = QDVD::VideoTrack::Aspect_16_9;
+        } else if (checkRatio(ratio, 4.0/3.0)) {
+            m_aspectRatio = QDVD::VideoTrack::Aspect_4_3;
+        } else {
+            m_aspectRatio = QDVD::VideoTrack::Aspect_Unknown;
         }
-
-        m_aspectRatio =
-            (QDVD::VideoTrack::AspectRatio)(info["ASPECT_RATIO"].toInt());
-        m_frameRate = info["FRAME_RATE"].toFloat();
-        m_audioStreams = info["AUDIO_STREAMS"].toInt();
-        m_dvdCompatible = (info["DVD_COMPATIBLE"] == "1");
-        m_duration = KMF::Time(info["DURATION"].toDouble());
-        m_resolution = QSize(info["WIDTH"].toInt(), info["HEIGHT"].toInt());
-
-        /*
-         * kDebug() << "File: " << m_file;
-         * kDebug() << "Output: " << run.output();
-         * kDebug() << "Aspect: " << m_aspectRatio;
-         * kDebug() << "Frame rate: " << m_frameRate;
-         * kDebug() << "Audio: " << m_audioStreams;
-         * kDebug() << "Compatible: " << m_dvdCompatible;
-         * kDebug() << "Duration: " << m_duration;
-         */
-        return true;
+        m_frameRate = video.getFrameRate();
+        m_audioStreams = video.getNumAudioStreams();
+        m_dvdCompatible = video.getCodec()=="mpeg2video";
+        m_duration = KMF::Time(video.getDuration());
+        m_resolution = QSize(video.getWidth(), video.getHeight());
     }
 
     return false;
 }
 
-bool KMFMediaFile::frame(QTime pos, QString output) const
+QImage KMFMediaFile::frame(QTime pos) const
 {
-    Run run(QString("kmf_frame \"%1\" %2 \"%3\"").arg(m_file)
-            .arg(KMF::Time(pos).toString()).arg(output));
-
-    return (run.exitStatus() == 0);
+    VideoFile video;
+    if(video.open(m_file)) {
+        video.seek(KMF::Time(pos).toMSec());
+        return (video.getFrame());
+    }
+    return QImage();
 }
 
 const KMFMediaFile &KMFMediaFile::mediaFile(const QString &file)
