@@ -19,6 +19,7 @@
 // **************************************************************************
 
 #include "kmftools.h"
+#include "run.h"
 
 #include <QtCore/QDir>
 #include <QtCore/QFile>
@@ -49,6 +50,7 @@
 #include <errno.h>
 #include <fontconfig/fontconfig.h>
 #include <sys/stat.h>
+#include <stdlib.h>
 
 #include "Q4puGenericSignalSpy.h"
 
@@ -625,16 +627,8 @@ void KMF::Tools::cleanFiles(const QString &d, const QStringList &files)
         }
     }
 
-    // Remove dirs if they are empty
-    int pos = -1;
-
-    while ((pos = d.lastIndexOf(QDir::separator(), pos)) != -1) {
-        QString s = d.left(pos--);
-
-        if (dir.rmdir(s) == false) {
-            break;
-        }
-    }
+    // Remove dir if it is empty
+    ::rmdir(QFile::encodeName(d).constData());
 }
 
 QImage KMF::Tools::variantList2Image(QVariant v)
@@ -783,3 +777,22 @@ QString KMF::Tools::changeExt(const QString &f, const QString &newExt)
 
     return newStr;
 }
+
+int KMF::Tools::dvdauthorVersion()
+{
+    static int version=-1;
+
+    if (-1==version) {
+        Run run(QString("kmf_dvdauthor_version"));
+
+        if (run.exitStatus() == 0) {
+            QStringList lines = run.output().split('\n');
+            if(lines.count()) {
+                version=lines.at(0).toInt();
+            }
+        }
+    }
+
+    return version;
+}
+
