@@ -90,9 +90,9 @@ class KDE_EXPORT Cell : public Base
         {
         };
         Cell(QTime start, QTime length, QString name, bool chapter = true, bool hidden =
-                false) : m_cell(0), m_chapter(chapter), m_hidden(hidden), m_start(start), m_length(
+                false, QString previewFile=QString()) : m_cell(0), m_chapter(chapter), m_hidden(hidden), m_start(start), m_length(
                                  length),
-                         m_startSector(0), m_endSector(0), m_name(name)
+                         m_startSector(0), m_endSector(0), m_name(name), m_preview(previewFile)
         {
         };
 #ifdef HAVE_LIBDVDREAD
@@ -132,6 +132,10 @@ class KDE_EXPORT Cell : public Base
         {
             return m_hidden;
         };
+        QString previewFile() const
+        {
+            return m_preview;
+        }
         virtual uint64_t size() const;
 
         virtual QString toString() const;
@@ -157,6 +161,10 @@ class KDE_EXPORT Cell : public Base
         {
             m_hidden = h;
         }
+        void setPreviewFile(const QString &file)
+        {
+            m_preview = file;
+        }
 
     private:
         int m_cell;
@@ -167,6 +175,7 @@ class KDE_EXPORT Cell : public Base
         int m_startSector;
         int m_endSector;
         QString m_name;
+        QString m_preview;
 };
 
 typedef QList<Cell> CellList;
@@ -291,6 +300,29 @@ class KDE_EXPORT Subtitle : public Track
 
         QString horizontalAlign() const;
 
+        int leftMargin() const
+        {
+            return m_leftMargin;
+        }
+        int rightMargin() const
+        {
+            return m_rightMargin;
+        }
+        int topMargin() const
+        {
+            return m_topMargin;
+        }
+        int bottomMargin() const
+        {
+            return m_bottomMargin;
+        }
+        void setMargins(int left, int right, int top, int bottom)
+        {
+            m_leftMargin=left;
+            m_rightMargin=right;
+            m_topMargin=top;
+            m_bottomMargin=bottom;
+        }
     protected:
         static const char *subpType[16];
         static const char *hAlign[4];
@@ -303,6 +335,10 @@ class KDE_EXPORT Subtitle : public Track
         QFont   m_font;
         Qt::Alignment m_align;
         QString m_encoding;
+        int     m_leftMargin,
+                m_rightMargin,
+                m_topMargin,
+                m_bottomMargin;
 };
 
 class KDE_EXPORT AudioTrack : public Track
@@ -450,6 +486,10 @@ class KDE_EXPORT VideoTrack : public Track
         {
             return AspectRatioString[aspect];
         };
+        static QString aspectRatioString(uint aspect)
+        {
+            return AspectRatioString[aspect<4 ? aspect : 0];
+        };
         virtual uint rtti() const
         {
             return VIDEO;
