@@ -43,6 +43,7 @@
 #include <kmftools.h>
 #include <kmediafactory/job.h>
 #include <kmediafactory/object.h>
+#include <outputpluginsettings.h>
 #include "outputplugin.h"
 
 static const char startString[] = I18N_NOOP("DVD Folder");
@@ -92,6 +93,11 @@ class DVDDirectoryJob : public KMF::Job
             if (m_error) {
                 clean(projectDir);
             }
+            else if (OutputPluginSettings::autoClean()){
+                KMF::Tools::cleanFiles(projectDir + "media", QStringList() << "dummy.mpg" << "dummy.pnm" << "*.sub.mpg" << "*.xml");
+                KMF::Tools::cleanFiles(projectDir + "menus", QStringList() << "*.mpg" << "*.pnm" << "*.png" << "*.xml");
+                QFile::remove(projectDir + "dvdauthor.xml");
+            }
 
             message(subid, KMF::Done);
             message(msgId(), KMF::Done);
@@ -182,6 +188,7 @@ class DVDDirectoryJob : public KMF::Job
             KMF::Tools::cleanFiles(projectDir + "DVD/AUDIO_TS");
             KMF::Tools::cleanFiles(projectDir + "DVD/VIDEO_TS",
                     QStringList() << "*.VOB" << "*.BUP" << "*.IFO");
+            KMF::Tools::cleanFiles(projectDir + "DVD");
         }
 
         uint subId()
@@ -208,8 +215,7 @@ DvdDirectoryObject::DvdDirectoryObject(QObject *parent)
 {
     setObjectName("dvddir");
     setTitle(i18n("DVD Folder"));
-    dvdCleanDirectory = new KAction(KIcon("edit-delete"),
-            i18n("Clean Folder"), this);
+    dvdCleanDirectory = new KAction(KIcon("edit-delete"), i18n("Clean"), this);
     plugin()->actionCollection()->addAction("ddob_cleandir", dvdCleanDirectory);
     connect(dvdCleanDirectory, SIGNAL(triggered()), SLOT(clean()));
 }
