@@ -41,7 +41,6 @@
 #include <subtitleoptions.h>
 
 #include <kmfmediafile.h>
-#include <kmfmultiurldialog.h>
 #include <kmftime.h>
 #include "slideshowobject.h"
 
@@ -222,10 +221,14 @@ SlideshowProperties::SlideshowProperties(QWidget *parent, bool showSubPage) : KD
     connect(addAudioButton, SIGNAL(clicked()), this, SLOT(addAudio()));
     connect(removeAudioButton, SIGNAL(clicked()), this, SLOT(removeAudio()));
     connect(durationSpinBox, SIGNAL(valueChanged(int)), this, SLOT(updateInfo()));
+ 
+    restoreDialogSize(KConfigGroup(KGlobal::config(), metaObject()->className()));
 }
 
 SlideshowProperties::~SlideshowProperties()
 {
+    KConfigGroup cg(KGlobal::config(), metaObject()->className());
+    KDialog::saveDialogSize(cg);
 }
 
 void SlideshowProperties::getData(SlideshowObject &obj) const
@@ -273,7 +276,11 @@ void SlideshowProperties::addSlides(const SlideList &slides)
 
         list.append(item);
     }
+    #if KDE_IS_VERSION(4, 6, 90)
+    KIO::PreviewJob *job =  KIO::filePreview(list, QSize(80, 60));
+    #else
     KIO::PreviewJob *job =  KIO::filePreview(list, 80, 60);
+    #endif
     connect(job, SIGNAL(gotPreview(const KFileItem &, const QPixmap &)),
             this, SLOT(gotPreview(const KFileItem &, const QPixmap &)));
     updateInfo();
@@ -376,7 +383,7 @@ void SlideshowProperties::add()
             i18n(
                     "*.jpg *.png *.pdf *.odp *.odt *.ods *.odx *.sxw *.sxc *.sxi \
             *.ppt *.xls *.doc|Pictures, Presentations\n*.*|All files"                                                                                   ),
-            this);
+            this, i18n("Select Slideshow Files"));
 
     if (pics.count() > 0) {
         addSlides(m_sob->slideList(pics, this));
@@ -396,8 +403,8 @@ void SlideshowProperties::addAudio()
 {
     QStringList files = KFileDialog::getOpenFileNames(
             KUrl("kfiledialog:///<SlideshowAudioFiles>"),
-            i18n("*.mp3 *.wav *.ogg|Audio Files"),
-            this);
+            "audio/mpeg audio/mp2 audio/x-wav audio/ogg",
+            this, i18n("Select Audio File"));
 
     if (files.count() > 0) {
         addAudio(files);
