@@ -209,9 +209,14 @@ QStringList TemplateObject::menus()
     return m_menu.menus();
 }
 
-QImage TemplateObject::preview(const QString &menu)
+int TemplateObject::chaptersPerPage(const QString &page)
 {
-    return m_menu.makeMenuPreview(menu);
+    return m_menu.chaptersPerPage(page);
+}
+
+QImage TemplateObject::preview(const QString &menu, int title, int chapter)
+{
+    return m_menu.makeMenuPreview(menu, title, chapter);
 }
 
 QPixmap TemplateObject::pixmap() const
@@ -267,20 +272,21 @@ void TemplateObject::slotProperties()
         dialog->addPage(page, title(), "kmediafactory");
     }
 
-    dialog->exec();
-
-    /*
-    * kDebug() << &m_customProperties;
-    * KConfigSkeletonItem::List list = m_customProperties.items();
-    * KConfigSkeletonItem::List::iterator it;
-    * for(it = list.begin(); it != list.end(); ++it)
-    *  kDebug() << (*it)->group() << " / " <<
-    *      (*it)->key() << " = " << (*it)->property();
-    */
-    if (dialog->result() == QDialog::Accepted) {
-        interface()->setDirty(KMF::Template);
+    if(QDialog::Accepted==dialog->exec()) {
+        emit updated();
     }
 
+    /*
+    kDebug() << &m_customProperties;
+    KConfigSkeletonItem::List list = m_customProperties.items();
+    KConfigSkeletonItem::List::iterator it;
+    for (it = list.begin(); it != list.end(); ++it) {
+        kDebug() << (*it)->group() << "/" << (*it)->key() << "=" << (*it)->property().toString();
+        if (dialog->result() == QDialog::Accepted) {
+            interface()->setDirty(KMF::Template);
+        }
+    }
+    */
     kapp->removeTranslator(&kmftr);
     delete dialog;
 }
