@@ -53,9 +53,22 @@ enum Columns {
     COL_START,
     COL_LENGTH,
     COL_HIDDEN,
+    COL_THUMBNAIL,
     COL_COUNT
 };
 
+static QString getFile(const QString &f)
+{
+    QString d(f);
+
+    int slashPos=d.lastIndexOf('/');
+
+    if(slashPos!=-1)
+        d.remove(0, slashPos+1);
+
+    return d;
+}
+
 class CellListModel : public QAbstractListModel
 {
     public:
@@ -140,11 +153,32 @@ class CellListModel : public QAbstractListModel
                                 return KMF::Time(m_data->at(index.row()).length()).toString();
                             }
 
+                        case COL_THUMBNAIL:
+                            return m_data->at(index.row()).isHidden()
+                                    ? i18n("Not Applicable")
+                                    : m_data->at(index.row()).previewFile().isEmpty() 
+                                        ? i18n("Generated") : getFile(m_data->at(index.row()).previewFile());
                         default:
                             break;
                     }
                     break;
 
+                case Qt::ToolTipRole:
+                    if (COL_THUMBNAIL == index.column() && 
+                        !m_data->at(index.row()).previewFile().isEmpty() &&  !m_data->at(index.row()).isHidden()) {
+                            return m_data->at(index.row()).previewFile();
+                    }
+                    break;
+
+                case Qt::FontRole:
+                    if (COL_THUMBNAIL == index.column() && 
+                        (m_data->at(index.row()).previewFile().isEmpty() ||  m_data->at(index.row()).isHidden())) {
+                        QFont font;
+                        font.setItalic(true);
+                        return font;
+                    }
+                    break;
+
                 case Qt::CheckStateRole:
                     if (COL_HIDDEN == index.column()) {
                         return m_data->at(index.row()).isHidden() ? Qt::Unchecked : Qt::Checked;
@@ -176,6 +210,9 @@ class CellListModel : public QAbstractListModel
 
                     case COL_LENGTH:
                         return i18n("Length");
+                        
+                    case COL_THUMBNAIL:
+                        return i18n("Thumbnail");
                 }
             } else if (role == Qt::DecorationRole) {
                 switch (column) {
@@ -238,8 +275,12 @@ Chapters::Chapters(QWidget *parent)
     connect(playButton, SIGNAL(clicked()), this, SLOT(slotPlay()));
     connect(chaptersView, SIGNAL(customContextMenuRequested(const QPoint &)),
             this, SLOT(slotContextMenu(const QPoint &)));
+    connect(chaptersView, SIGNAL(doubleClicked(const QModelIndex &)),
+            this, SLOT(chapterDoubleClicked(const QModelIndex &)));
     connect(customPreviewButton, SIGNAL(clicked()),
             this, SLOT(saveCustomPreview()));
+    connect(chapterThumbnailButton, SIGNAL(clicked()),
+            this, SLOT(chapterThumbnailButtonClicked()));
     startButton->setIcon(KIcon("media-skip-backward"));
     rewButton->setIcon(KIcon("media-seek-backward"));
     prevButton->setIcon(KIcon("arrow-left"));
@@ -260,19 +301,21 @@ Chapters::~Chapters()
 void Chapters::showEvent(QShowEvent *event)
 {
     Q_UNUSED(event)
-    chaptersView->header()->setResizeMode(0, QHeaderView::Stretch);
-    chaptersView->header()->setResizeMode(1, QHeaderView::ResizeToContents);
-    chaptersView->header()->setResizeMode(2, QHeaderView::ResizeToContents);
-    chaptersView->header()->setResizeMode(3, QHeaderView::ResizeToContents);
-    chaptersView->header()->setStretchLastSection(false);
+    chaptersView->header()->setResizeMode(COL_NAME, QHeaderView::ResizeToContents);
+    chaptersView->header()->setResizeMode(COL_START, QHeaderView::ResizeToContents);
+    chaptersView->header()->setResizeMode(COL_LENGTH, QHeaderView::ResizeToContents);
+    chaptersView->header()->setResizeMode(COL_HIDDEN, QHeaderView::ResizeToContents);
+    chaptersView->header()->setResizeMode(COL_THUMBNAIL, QHeaderView::ResizeToContents);
+    chaptersView->header()->setStretchLastSection(true);
     KConfigGroup cg = KGlobal::config()->group("ChaptersDlg");
     splitter->setSizes(cg.readEntry("splitter", QList<int>() << 330 << 330));
 }
 
-void Chapters::setData(const QDVD::CellList &cells, const VideoObject *obj)
+void Chapters::setData(const QDVD::CellList &cells, const VideoObject *obj, VideoOptions *vidOpt)
 {
     m_cells = cells;
     m_obj = obj;
+    m_vidOpt = vidOpt;
 
     if (m_model) {
         delete m_model;
@@ -461,8 +504,18 @@ void Chapters::slotContextMenu(const QPoint &p)
     popup->addAction(i18n("Delete All"), this, SLOT(deleteAll()));
     popup->addAction(i18n("Rename All"), this, SLOT(renameAll()));
     popup->addAction(i18n("Auto Chapters"), this, SLOT(autoChapters()));
-    popup->addAction(i18nc("Import chapter file", "Import"),
-            this, SLOT(import()));
+    popup->addAction(i18nc("Import chapter file", "Import..."), this, SLOT(import()));
+    
+    popup->addSeparator();
+    popupIndex=chaptersView->indexAt(p);
+    QAction *act=popup->addAction(i18n("Set Custom Thumbnail..."), this, SLOT(setThumbnail()));
+    if(!popupIndex.isValid()) {
+        act->setEnabled(false);
+    }
+    act=popup->addAction(i18n("Unset Custom Thumbnail"), this, SLOT(unsetThumbnail()));
+    if(!popupIndex.isValid() || m_cells[popupIndex.row()].previewFile().isEmpty()) {
+        act->setEnabled(false);
+    }
     popup->exec(chaptersView->viewport()->mapToGlobal(p));
 }
 
@@ -533,7 +586,7 @@ void Chapters::autoChapters()
 void Chapters::import()
 {
     QString chapterFile = KFileDialog::getOpenFileName(
-            KUrl("kfiledialog:///<Chapters"), "*.*|All files");
+            KUrl("kfiledialog:///<Chapters>"), QString(), this, i18n("Select Chapters File"));
 
     if (!chapterFile.isEmpty()) {
         QMap<QString, QString> chapters = KMF::Tools::readIniFile(chapterFile);
@@ -560,12 +613,7 @@ void Chapters::import()
 
 void Chapters::saveCustomPreview()
 {
-    int serial = m_obj->interface()->serial();
-    QDir dir(m_obj->interface()->projectDir("media"));
-
-    m_preview.sprintf("%3.3d_preview.png", serial);
-    m_preview = dir.filePath(m_preview);
-    m_obj->getFrame(m_pos, m_preview);
+    m_vidOpt->setPreviewUrl("position:/"+KMF::Time(m_pos).toString());
 }
 
 void Chapters::checkLengths()
@@ -626,4 +674,50 @@ void Chapters::slotPlay()
     }
 }
 
+void Chapters::setThumbnail()
+{
+    if(popupIndex.isValid()) {
+        setThumbnail(popupIndex.row());
+    }
+}
+
+void Chapters::chapterThumbnailButtonClicked()
+{
+    if(chaptersView->currentIndex().isValid()) {
+        m_cells[chaptersView->currentIndex().row()].setPreviewFile("position:/"+KMF::Time(m_pos).toString());
+    }
+}
+
+void Chapters::unsetThumbnail()
+{
+    if(popupIndex.isValid()) {
+        m_cells[popupIndex.row()].setPreviewFile(QString());
+    }
+}
+
+void Chapters::chapterDoubleClicked(const QModelIndex &index)
+{
+    if(index.isValid() && COL_THUMBNAIL==index.column()) {
+        setThumbnail(index.row());
+    }
+}
+
+void Chapters::setThumbnail(int index)
+{
+    QString existing = m_cells[index].previewFile(),
+            fileName = KFileDialog::getOpenFileName(KUrl(existing.isEmpty() ? "kfiledialog:///<Thumbnails>" : existing), 
+                                                    "image/jpeg image/png", this, i18n("Select Thumbnail File"));
+
+    if (!fileName.isEmpty()) {
+        QImage img(fileName);
+        
+        if(img.isNull()) {
+            KMessageBox::error(this, i18n("%1 is not a valid image file", fileName));
+        }
+        else {
+            m_cells[index].setPreviewFile(fileName);
+        }
+    }
+}
+
 #include "chapters.moc"
