@@ -28,6 +28,7 @@
 #include <KFontRequester>
 #include <KMessageBox>
 #include <KUrlRequester>
+#include <KFileDialog>
 #include <KIO/NetAccess>
 
 #include <kmflanguagewidgets.h>
@@ -39,7 +40,9 @@ SubtitleOptionsWidget::SubtitleOptionsWidget(QWidget *parent, bool wantFile) : Q
     languageCombo->setModel(&m_languageModel);
     encodingCombo->model()->sort(0);
 
-    if (!wantFile) {
+    if (wantFile) {
+        subtitleUrl->fileDialog()->setCaption(i18n("Select Subtitle File"));
+    } else {
         delete subtitleUrl;
         subtitleUrl = 0L;
         delete subtitleFileLabel;
@@ -134,10 +137,13 @@ SubtitleOptions::SubtitleOptions(QWidget *parent)
     setMainWidget(m_widget = new SubtitleOptionsWidget(this, true));
     setButtons(KDialog::Ok | KDialog::Cancel);
     setCaption(i18n("Subtitle Options"));
+    restoreDialogSize(KConfigGroup(KGlobal::config(), metaObject()->className()));
 }
 
 SubtitleOptions::~SubtitleOptions()
 {
+    KConfigGroup cg(KGlobal::config(), metaObject()->className());
+    KDialog::saveDialogSize(cg);
 }
 
 void SubtitleOptions::accept()
