@@ -109,17 +109,23 @@ class ConvertSubtitlesJob : public KMF::Job
             textsub.setAttribute("filename", subtitleFile);
             textsub.setAttribute("vertical-alignment", subtitle.verticalAlign());
             textsub.setAttribute("horizontal-alignment", subtitle.horizontalAlign());
-            textsub.setAttribute("left-margin", 40);
-            textsub.setAttribute("right-margin", 40);
-            textsub.setAttribute("top-margin", 30);
-            textsub.setAttribute("bottom-margin", 40);
+            textsub.setAttribute("left-margin", subtitle.leftMargin());
+            textsub.setAttribute("right-margin", subtitle.rightMargin());
+            textsub.setAttribute("top-margin", subtitle.topMargin());
+            textsub.setAttribute("bottom-margin", subtitle.bottomMargin());
             textsub.setAttribute("movie-width", "720");
             textsub.setAttribute("characterset", subtitle.encoding());
 
             if (type == "DVD-PAL") {
+                if(KMF::Tools::dvdauthorVersion()>=KDE_MAKE_VERSION(0, 7, 0)) {
+                    root.setAttribute("format", "PAL");
+                }
                 textsub.setAttribute("movie-fps", "25");
                 textsub.setAttribute("movie-height", "574");
             } else   {
+                if(KMF::Tools::dvdauthorVersion()>=KDE_MAKE_VERSION(0, 7, 0)) {
+                    root.setAttribute("format", "NTSC");
+                }
                 textsub.setAttribute("movie-fps", "29.97");
                 textsub.setAttribute("movie-height", "478");
             }
@@ -361,6 +367,7 @@ bool VideoObject::fromXML(const QDomElement &element)
                             KMF::Time start(e2.attribute("start"));
                             KMF::Time length(e2.attribute("length"));
                             QString name = e2.attribute("name");
+                            QString previewFile = e2.attribute("preview");
                             bool chapter = (e2.attribute("chapter") == "1");
                             bool hidden = (e2.attribute("hidden") == "1");
 
@@ -384,7 +391,7 @@ bool VideoObject::fromXML(const QDomElement &element)
                                 name = start.toString("h:mm:ss");
                             }
 
-                            addCell(QDVD::Cell(start, length, name, chapter, hidden));
+                            addCell(QDVD::Cell(start, length, name, chapter, hidden, previewFile));
                         } else if (e2.tagName() == "audio")    {
                             QDVD::AudioTrack a(e2.attribute("language",
                                                        VideoPluginSettings::defaultAudioLanguage()));
@@ -419,6 +426,25 @@ bool VideoObject::fromXML(const QDomElement &element)
                                     QString("%1").arg(Qt::AlignHCenter | Qt::AlignBottom));
                             s.setAlignment(QFlags<Qt::AlignmentFlag>(a.toInt()));
                             s.setFont(font);
+                            if (e2.hasAttribute("margins")) {
+                                QStringList margins=e2.attribute("margins").split(',', QString::SkipEmptyParts);
+
+                                static const int constMarginMin=10;
+                                static const int constMarginMax=250;
+                                if(4==margins.count()) {
+                                    int left=margins[0].toInt(),
+                                        right=margins[1].toInt(),
+                                        top=margins[2].toInt(),
+                                        bottom=margins[3].toInt();
+
+                                    if(left>=constMarginMin && left<=constMarginMax &&
+                                       right>=constMarginMin && right<=constMarginMax &&
+                                       top>=constMarginMin && top<=constMarginMax &&
+                                       bottom>=constMarginMin && bottom<=constMarginMax) {
+                                        s.setMargins(left, right, top, bottom);
+                                    }
+                                }
+                            }
                             addSubtitle(s);
                         }
                     }
@@ -497,6 +523,8 @@ void VideoObject::toXML(QDomElement *element) const
         e.setAttribute("length", KMF::Time(cell.length()).toString());
         e.setAttribute("chapter", cell.isChapter());
         e.setAttribute("hidden", cell.isHidden());
+        if(!cell.previewFile().isEmpty())
+            e.setAttribute("preview", cell.previewFile());
         video.appendChild(e);
     }
 
@@ -599,58 +627,46 @@ QVariant VideoObject::writeDvdAuthorXml(QVariantList args) const
 
     // Add cells
     KMF::Time pos;
-    bool open = false;
     QDomElement vob;
+    int cellIndex = 0;
     QDVD::Cell cell;
-    int file = 0;
 
-    for (i = 0; i <= m_cells.count(); ++i) {
-        if (!open) {
-            vob = doc.createElement("vob");
+    for (i = 0; i < m_files.count(); ++i) {
+        const QString file = videoFileFind(i);
+        QTime fileDuration = duration(m_files.at(i));
+        vob = doc.createElement("vob");
 
-            if (m_type != "dummy") {
-                vob.setAttribute("file", videoFileFind(i));
-            } else   {
-                vob.setAttribute("file", dir.filePath("dummy.mpg"));
+        kDebug() << "File: " << file;
+        if (m_type != "dummy") {
+            vob.setAttribute("file", videoFileFind(i));
+        } else   {
+            vob.setAttribute("file", dir.filePath("dummy.mpg"));
+        }
+        while (cellIndex < m_cells.count() &&
+            (KMF::Time(cell.start()) < pos + fileDuration)) {
+            cell = m_cells[cellIndex++];
+            KMF::Time start(cell.start());
+            KMF::Time end(cell.start());
+
+            start -= pos;
+            QDomElement c = vob.ownerDocument().createElement("cell");
+
+            c.setAttribute("start", KMF::Time(start).toString());
+
+            if (cell.length() == KMF::Time()) {
+                c.setAttribute("end", "-1");
+            } else {
+                end -= pos;
+                end += cell.length();
+                c.setAttribute("end", end.toString());
             }
-
-            open = true;
+            c.setAttribute("chapter", cell.isChapter());
+            vob.appendChild(c);
+            kDebug() << "Cell: " << start << ", " << end << cellIndex << m_cells.count() 
+                     << KMF::Time(cell.start()) << pos + duration(file);
         }
-
-        if ((KMF::Time(cell.start()) > pos + duration(m_files[file])) ||
-            (i >= m_cells.count()))
-        {
-            pos += duration(m_files[file]);
-            pgc.appendChild(vob);
-
-            if ((i >= m_files.count()) || (i >= m_cells.count())) {
-                break;
-            }
-
-            open = false;
-            ++file;
-        }
-
-        cell = m_cells[i];
-        KMF::Time start(cell.start());
-        KMF::Time end(cell.start());
-
-        start -= pos;
-        QDomElement c = vob.ownerDocument().createElement("cell");
-
-        c.setAttribute("start", KMF::Time(start).toString());
-
-        if (cell.length() == KMF::Time()) {
-            c.setAttribute("end", "-1");
-        } else {
-            end -= pos;
-            end += cell.length();
-            c.setAttribute("end", end.toString());
-        }
-
-        c.setAttribute("chapter", cell.isChapter());
-        vob.appendChild(c);
-        // kDebug() << "Cell: " << start << ", " << end;
+        pgc.appendChild(vob);
+        pos += fileDuration;
     }
 
     QString postString;
@@ -769,6 +785,7 @@ void VideoObject::slotProperties()
         dlg->getData(*this);
         interface()->setDirty(KMF::Media);
     }
+    delete dlg;
 }
 
 QPixmap VideoObject::pixmap() const
@@ -829,9 +846,8 @@ QString VideoObject::videoFileName(KMF::Time *time) const
     return QString();
 }
 
-QImage VideoObject::getFrame(QTime time, QString frameFile) const
+QImage VideoObject::getFrame(QTime time) const
 {
-    bool ok = false;
     KMF::Time t = time;
 
     foreach (const QString &file, m_files) {
@@ -839,19 +855,13 @@ QImage VideoObject::getFrame(QTime time, QString frameFile) const
         const KMFMediaFile &media = KMFMediaFile::mediaFile(file);
 
         if (t <= KMF::Time(media.duration())) {
-            media.frame(t, frameFile);
-            ok = true;
-            break;
+            return media.frame(t);
         } else   {
             t -= media.duration();
         }
     }
 
-    if (ok) {
-        return QImage(frameFile);
-    } else {
-        return QImage();
-    }
+    return QImage();
 }
 
 QImage VideoObject::preview(int chap) const
@@ -861,67 +871,83 @@ QImage VideoObject::preview(int chap) const
 
 QImage VideoObject::generatePreview(int chap, QSize desiredSize) const
 {
-    bool black = true;
-    int counter;
+    bool black = true, timeIsSet=false;
     QImage img;
-    QString cacheFile;
+    KMF::Time t;
 
     if (chap == MainPreview) {
         if (m_previewUrl.isValid()) {
-            img.load(m_previewUrl.path());
-            return img;
+            if(m_previewUrl.protocol()=="position") {
+                t=KMF::Time(m_previewUrl.path().replace("/", ""));
+                timeIsSet=true;
+            } else {
+                img.load(m_previewUrl.path());
+                return img;
+            }
         }
     }
 
-    KMF::Time t = chapter(chap).start();
-    QDir dir(interface()->projectDir("media"));
-    QString s;
-    cacheFile = dir.filePath(s.sprintf("%s_%s.pnm",
-                    (const char *)m_id.toLocal8Bit(),
-                    (const char *)t.toString().toLocal8Bit()));
-
-    if (img.load(cacheFile)) {
-        return img;
-    }
-
-    counter = 0;
-
-    while (black && counter < 60) {
-        img = getFrame(t, cacheFile);
-        black = isBlack(img);
-
-        if (black) {
-            kDebug() << "Black frame: " << t.toString();
+    QString cacheFile;
+    QString previewFile=MainPreview==chap ? QString() : chapter(chap).previewFile();
+    bool    loadedFromCache=false;
+    
+    if(!previewFile.isEmpty()) {
+        KUrl url(previewFile);
+        if(url.protocol()=="position") {
+            t=KMF::Time(url.path().replace("/", ""));
+            timeIsSet=true;
+        } else {
+            img.load(previewFile);
         }
-
-        t += VideoPluginSettings::blackFrameJump();
-        ++counter;
+    } else if(VideoPluginSettings::usePreviewCache()) {
+        QDir dir(interface()->projectDir("media"));
+        QString s;
+        if(!timeIsSet) {
+            t = chapter(chap).start();
+        }
+        cacheFile = dir.filePath(s.sprintf("%s_%s.png",
+                        (const char *)m_id.toLocal8Bit(),
+                        (const char *)t.toString().toLocal8Bit()));
+        loadedFromCache=img.load(cacheFile);
     }
-    QSize templateRatio = desiredSize.width() > 0
-                          ? QSize(1, 1)
-                          : (interface()->aspectRatio() == QDVD::VideoTrack::Aspect_4_3)
-                          ? QSize(4, 3) : QSize(16, 9);
-    QSize videoRatio = (aspect() == QDVD::VideoTrack::Aspect_4_3) ?
-                       QSize(4, 3) : QSize(16, 9);
-    QSize imageRatio = KMF::Tools::guessRatio(img.size(), videoRatio);
-    QSize templateSize = desiredSize.width() > 0 ? desiredSize : KMF::Tools::maxResolution(
-            interface()->projectType());
-    QSize imageSize = img.size();
-    QSize res = KMF::Tools::resolution(imageSize, imageRatio,
-            templateSize, templateRatio);
 
-    img = img.scaled(res, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+    if(img.isNull()) {
+        int counter = 0;
+        if(!timeIsSet) {
+            t = chapter(chap).start();
+        }
+        while (black && counter < 60) {
+            img = getFrame(t);
+            black = isBlack(img);
 
-    /*
-     * kDebug() << "Template size: " << templateSize;
-     * kDebug() << "Template ratio:" << templateRatio;
-     * kDebug() << "Video ratio:" << videoRatio;
-     * kDebug() << "Image size:" << imageSize;
-     * kDebug() << "Image ratio:" << imageRatio;
-     * kDebug() << "Final resolution:" << res;
-     */
-    if (!VideoPluginSettings::usePreviewCache()) {
-        QFile::remove(cacheFile);
+            if (black) {
+                kDebug() << "Black frame: " << t.toString();
+            }
+
+            t += VideoPluginSettings::blackFrameJump();
+            ++counter;
+        }
+    }
+
+    if (!loadedFromCache && VideoPluginSettings::usePreviewCache()) {
+        img.save(cacheFile);
+    }
+
+    if(!desiredSize.isNull()) {
+        QSize templateRatio = desiredSize.width() > 0
+                            ? QSize(1, 1)
+                            : (interface()->aspectRatio() == QDVD::VideoTrack::Aspect_4_3)
+                            ? QSize(4, 3) : QSize(16, 9);
+        QSize videoRatio = (aspect() == QDVD::VideoTrack::Aspect_4_3) ?
+                        QSize(4, 3) : QSize(16, 9);
+        QSize imageRatio = KMF::Tools::guessRatio(img.size(), videoRatio);
+        QSize templateSize = desiredSize.width() > 0 ? desiredSize : KMF::Tools::maxResolution(
+                interface()->projectType());
+        QSize imageSize = img.size();
+        QSize res = KMF::Tools::resolution(imageSize, imageRatio,
+                templateSize, templateRatio);
+
+        img = img.scaled(res, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
     }
 
     return img;
