@@ -28,6 +28,7 @@
 #include <KDebug>
 #include <KLocale>
 #include <KUrlRequester>
+#include <KFileDialog>
 
 #include <kmflanguagewidgets.h>
 #include <kmftools.h>
@@ -78,10 +79,15 @@ VideoOptions::VideoOptions(QWidget *parent)
             this, SLOT(subtitleRemoveClicked()));
     connect(audioPropertiesButton, SIGNAL(clicked()),
             this, SLOT(audioPropertiesClicked()));
+    previewUrl->setFilter("image/jpeg image/png");
+    previewUrl->fileDialog()->setCaption(i18n("Select Preview File"));
+    restoreDialogSize(KConfigGroup(KGlobal::config(), metaObject()->className()));
 }
 
 VideoOptions::~VideoOptions()
 {
+    KConfigGroup cg(KGlobal::config(), metaObject()->className());
+    KDialog::saveDialogSize(cg);
 }
 
 void VideoOptions::accept()
@@ -101,7 +107,7 @@ void VideoOptions::setData(const VideoObject &obj)
     aspectComboBox->setCurrentIndex((int)obj.aspect());
 
     m_obj = &obj;
-    m_chapters->setData(obj.cellList(), m_obj);
+    m_chapters->setData(obj.cellList(), m_obj, this);
     m_audioTracks = obj.audioTracks();
     m_audioModel.setLanguages(&m_audioTracks);
     audioListBox->setModel(&m_audioModel);
@@ -120,6 +126,11 @@ void VideoOptions::setData(const VideoObject &obj)
     enableButtons();
 }
 
+void VideoOptions::setPreviewUrl(const QString& url)
+{
+    previewUrl->setUrl(url);
+}
+
 void VideoOptions::getData(VideoObject &obj) const
 {
     obj.setTitle(titleEdit->text());
