@@ -117,13 +117,13 @@ void VideoPlugin::slotAddVideo()
 {
     QCheckBox *multipleFiles = new QCheckBox(0);
     QPointer<KFileDialog> dlg = new KFileDialog(KUrl("kfiledialog:///<AddVideo>"),
-                    "*.mpg *.mpeg *.vob|Video files\n*.*|All files",
+                    "video/mpeg",
                     kapp->activeWindow(), multipleFiles);
 
     multipleFiles->setText(i18n("Multiple files make multiple titles."));
     multipleFiles->setChecked(true);
     dlg->setOperationMode(KFileDialog::Opening);
-    dlg->setCaption(i18n("Open"));
+    dlg->setCaption(i18n("Select Video Files"));
     dlg->setMode(KFile::Files | KFile::ExistingOnly | KFile::LocalOnly);
     dlg->exec();
 
@@ -136,40 +136,38 @@ void VideoPlugin::slotAddVideo()
     if (m && (filenames.count() > 0)) {
         VideoObject *vob = 0;
 
-        for (QStringList::ConstIterator filename = filenames.begin();
-             filename != filenames.end(); ++filename)
-        {
-            QFileInfo fi(*filename);
+        foreach (const QString& filename, filenames) {
+            QFileInfo fi(filename);
 
             if (fi.isDir()) {
-                KMessageBox::error(kapp->activeWindow(),
+                KMessageBox::error(dlg->parentWidget(),
                         i18n("Cannot add directory."));
                 continue;
             }
 
-            if (multipleFiles->isChecked() || (filename == filenames.begin())) {
+            if (multipleFiles->isChecked() || (filename == filenames.first())) {
                 vob = new VideoObject(this);
             }
 
-            switch (vob->addFile(*filename)) {
+            switch (vob->addFile(filename)) {
                 case VideoObject::StatusOk:
                     break;
 
                 case VideoObject::StatusInvalidResolution:
                 {
-                    QSize res(KMFMediaFile::mediaFile(*filename).resolution());
-                    KMessageBox::error(kapp->activeWindow(),
+                    QSize res(KMFMediaFile::mediaFile(filename).resolution());
+                    KMessageBox::error(dlg->parentWidget(),
                             i18n("Cannot use %1.\n%2x%3 is an invalid resolution",
-                                    *filename, res.width(), res.height()));
+                                 filename, res.width(), res.height()));
                     delete vob;
                     vob = 0L;
                     break;
                 }
 
                 case VideoObject::StatusNonCompataible:
-                    KMessageBox::error(kapp->activeWindow(),
+                    KMessageBox::error(dlg->parentWidget(),
                         i18n("Cannot use %1.\nIt is not a DVD compatible file.",
-                                *filename));
+                             filename));
                     delete vob;
                     vob = 0L;
                     break;
@@ -181,19 +179,19 @@ void VideoPlugin::slotAddVideo()
 
             vob->setTitleFromFileName();
 
-            if (multipleFiles->isChecked() || (filename == filenames.end())) {
+            if (multipleFiles->isChecked() || (filename == filenames.last())) {
                 if (!m->addMediaObject(vob)) {
-                    KMessageBox::error(kapp->activeWindow(),
+                    KMessageBox::error(dlg->parentWidget(),
                             i18n("A DVD can only have a maximum of 99 titles.\n"),
                             i18n("Too Many Titles"));
                     delete vob;
                     break;
                 }
             }
-
-            if (vob && (1 == filenames.count())) {
-                vob->slotProperties();
-            }
+        }
+        if (vob && (!multipleFiles->isChecked() || filenames.count() == 1)) {
+            kapp->setActiveWindow(dlg->parentWidget());  // Otherwise activeWindow is not set and dialog has no parent!
+            vob->slotProperties();
         }
     }
     delete dlg;
