@@ -35,6 +35,7 @@
 #include "mediapage.h"
 #include "outputpage.h"
 #include "templatepage.h"
+#include <qdvdinfo.h>
 
 KMFProgressDialog::KMFProgressDialog(QWidget *parent)
     : KMF::ProgressDialog(parent)
@@ -182,6 +183,16 @@ void KMFPluginInterface::selectOutput(const QString &xml)
     kmfApp->project()->outputFromXML(doc.documentElement());
 }
 
+bool KMFPluginInterface::executableJobsRemaining()
+{
+    foreach (KMF::Job* job, m_jobs) {
+        if (!job->isFinished() && job->canBeExecuted()) {
+            return true;
+        }
+    }
+    return false;
+}
+
 void KMFPluginInterface::addJob(KMF::Job *job, KMF::JobDependency dependency)
 {
     switch (dependency) {
@@ -376,7 +387,7 @@ QString KMFPluginInterface::projectType()
     return QString();
 }
 
-QDVD::VideoTrack::AspectRatio KMFPluginInterface::aspectRatio() const
+uint KMFPluginInterface::aspectRatio() const
 {
     if (kmfApp->project()) {
         return kmfApp->project()->aspectRatio();
