@@ -60,7 +60,7 @@ class KMFPluginInterface : public KMF::PluginInterface
         virtual void setTitle(QString title);
         virtual QString projectDir(const QString &subDir = "");
         virtual QString projectType();
-        virtual QDVD::VideoTrack::AspectRatio aspectRatio() const;
+        virtual uint aspectRatio() const;
         virtual void setDirty(KMF::DirtyType type);
         virtual void setModified(KMF::DirtyType type);
         virtual QString lastSubType();
@@ -78,6 +78,7 @@ class KMFPluginInterface : public KMF::PluginInterface
         virtual void selectOutput(const QString &xml);
         virtual void addJob(KMF::Job *job, KMF::JobDependency dependency = KMF::None);
         virtual void addJob(KMF::Job *job, KMF::Job *dependency);
+        virtual bool executableJobsRemaining();
 
         void setUseMessageBox(bool useMessageBox)
         {
