@@ -43,7 +43,7 @@ int main(int argc, char **argv)
     about.addAuthor(ki18n("Petri Damsten"), ki18n("Developer"),
             "petri.damsten@iki.fi");
     about.addAuthor(ki18n("Craig Drummond"), ki18n("Developer"),
-            "craig.p.drummond@googlemail.com");
+            "craig.p.drummond@gmail.com");
     about.setOrganizationDomain("kde.org");
 
     KCmdLineOptions options;
@@ -56,11 +56,10 @@ int main(int argc, char **argv)
                                missingApps;
 
     requiredApps[i18n("DVD Author")] << "dvdauthor" << "spumux";
-    requiredApps[i18n("FFmpeg")] << "ffmpeg";
     requiredApps[i18n("MJPEG Tools")] << "mplex" << "ppmtoy4m" << "mpeg2enc";
 
     QMap<QString, QStringList>::iterator it(requiredApps.begin()),
-    end(requiredApps.end());
+                                         end(requiredApps.end());
 
     for (; it != end; ++it) {
         QStringList::iterator app(it.value().begin()),
