@@ -130,9 +130,8 @@ void OutputPage::contextMenuRequested(const QPoint &pos)
 void OutputPage::showLog()
 {
     LogView dlg(this);
-    KUrl url = kmfApp->project()->directory() + "kmf_log.html";
 
-    dlg.setData(url);
+    dlg.setData(makeLog());
     dlg.exec();
 }
 
@@ -185,10 +184,15 @@ void OutputPage::start()
     finished();
 }
 
-void OutputPage::jobDone(ThreadWeaver::Job *)
+void OutputPage::jobDone(ThreadWeaver::Job *job)
 {
+    Q_UNUSED(job);
     CHECK_IF_STOPPED();
     progressBar->setValue(progressBar->value() + 1);
+    if (ThreadWeaver::Weaver::instance()->queueLength() > 0 &&
+        kmfApp->interface()->executableJobsRemaining() == false) {
+        finished();
+    }
 }
 
 void OutputPage::finished()
@@ -197,7 +201,6 @@ void OutputPage::finished()
     kmfApp->interface()->clearJobs();
     kmfApp->project()->finished();
     m_type = "";
-    makeLog();
     showLogPushBtn->setEnabled(true);
     stopPushBtn->setEnabled(false);
     startButton->setEnabled(true);
@@ -340,7 +343,7 @@ void OutputPage::log(uint id, const QString &msg)
     }
 }
 
-void OutputPage::makeLog()
+QString OutputPage::makeLog()
 {
     QString s = QString(
             "<?xml version=\"1.0\" encoding=\"utf-8\" ?>\n" \
@@ -381,7 +384,7 @@ void OutputPage::makeLog()
     }
     s += "</div></body></html>";
 
-    KMF::Tools::saveString2File(kmfApp->project()->directory() + "kmf_log.html", s);
+    return s;
 }
 
 #include "outputpage.moc"
