@@ -64,7 +64,7 @@ class OutputPage : public QWidget, public Ui::OutputPage
         QString m_type;
         QStandardItemModel *m_model;
 
-        void makeLog();
+        QString makeLog();
 };
 
 #endif // OUTPUTPAGE_H
