@@ -34,6 +34,7 @@
 #include <KPageDialog>
 #include <KXMLGUIFactory>
 
+#include <kmediafactorysettings.h>
 #include <kmfimageview.h>
 #include <kmftools.h>
 #include "kmediafactory.h"
@@ -41,13 +42,12 @@
 
 TemplatePage::TemplatePage(QWidget *parent)
     : QWidget(parent)
-    , m_menu(0)
-    , m_scaled(false)
 {
     setupUi(this);
     templates->setSpacing(5);
     templates->setItemDelegate(new KFileItemDelegate(this));
     templates->setIconSize(QSize(KIconLoader::SizeHuge, KIconLoader::SizeHuge));
+    templatePreview->setScaled(KMediaFactorySettings::previewScaled());
     connect(templates, SIGNAL(customContextMenuRequested(const QPoint &)),
             this, SLOT(contextMenuRequested(const QPoint &)));
     connect(templatePreview,
@@ -91,9 +91,10 @@ void TemplatePage::selectionChanged(const QItemSelection &selected,
 
         if (ob) {
             if (ob->clicked() == false) {
-                m_menu = 0;
+                m_menu.reset();
                 kmfApp->project()->setTemplateObj(ob);
                 updatePreview(index.row());
+                connect(ob, SIGNAL(updated()), SLOT(updatePreview()));
             } else   {
                 templates->selectionModel()->select(deselected, QItemSelectionModel::ClearAndSelect);
             }
@@ -146,8 +147,8 @@ void TemplatePage::updatePreview(int n)
                 kmfApp->project()->templateObjects()->at(selected[0].row());
             QStringList menus = ob->menus();
 
-            if (m_menu < menus.count()) {
-                menu = menus[m_menu];
+            if (m_menu.page < menus.count()) {
+                menu = menus[m_menu.page];
             } else {
                 menu = "Main";
             }
@@ -155,7 +156,7 @@ void TemplatePage::updatePreview(int n)
 
         KMF::TemplateObject *ob = kmfApp->project()->templateObjects()->at(n);
         // Scale to real 4:3. Should get aspect ratio from template plugin?
-        QImage image = ob->preview(menu).scaled(768, 576, Qt::IgnoreAspectRatio,
+        QImage image = ob->preview(menu, m_menu.title, m_menu.chapter).scaled(768, 576, Qt::IgnoreAspectRatio,
                 Qt::SmoothTransformation);
         templatePreview->setImage(image);
         kmfApp->interface()->setUseMessageBox(false);
@@ -212,7 +213,7 @@ void TemplatePage::imageContextMenuRequested(const QPoint &pos)
     }
 
     scaledAction->setCheckable(true);
-    scaledAction->setChecked(m_scaled);
+    scaledAction->setChecked(KMediaFactorySettings::previewScaled());
 
     popup.addAction(scaledAction);
     popup.addAction(saveAction);
@@ -224,11 +225,47 @@ void TemplatePage::imageContextMenuRequested(const QPoint &pos)
     for (QStringList::Iterator it = menus.begin();
          it != menus.end(); ++it, ++i)
     {
-        action = new QAction(*it, this);
-        action->setCheckable(true);
-        action->setData(i);
-        action->setChecked(i == m_menu);
-        popup.addAction(action);
+        QList<MenuIndex> pages;
+
+        if(ob && kmfApp->project()->mediaObjects()) {
+            int                                      chaptersPerPage=ob->chaptersPerPage(*it),
+                                                     chapter(0);
+            QList<KMF::MediaObject *>                mo=kmfApp->project()->mediaObjects()->list();
+            QList<KMF::MediaObject *>::ConstIterator moIt(mo.constBegin()),
+                                                     moEnd(mo.constEnd());
+
+            for(int title=0; moIt!=moEnd; ++moIt, ++title) {
+                for(int ch=0; ch<(*moIt)->chapters(); ++ch) {
+                    chapter++;
+                    if(1==chapter) {
+                        pages.append(MenuIndex(i, title, ch));
+                    }
+                    else if(chapter==chaptersPerPage) {
+                        chapter=0;
+                    }
+                }
+            }
+        }
+        
+        if(pages.isEmpty()) {
+            pages.append(MenuIndex());
+        }
+        
+        QList<MenuIndex>::ConstIterator pageIt(pages.constBegin()),
+                                        pageEnd(pages.constEnd());
+                                  
+        for(int p=1; pageIt!=pageEnd; ++pageIt, ++p) {
+            QString pageName(QLatin1String("CHAPTER_PAGE")==(*it)
+                                ? i18n("Chapter Page") 
+                                : QLatin1String("Main")==(*it)
+                                    ? i18n("Main Page")
+                                    : *it);
+            action = new QAction(pages.count()>1 ? i18nc("<page name> <page number>", "%1 %2", pageName, p) : pageName, this);
+            action->setCheckable(true);
+            action->setData((*pageIt).toInt());
+            action->setChecked(*pageIt == m_menu);
+            popup.addAction(action);
+        }
     }
 
     QList<QAction *> templateActions;
@@ -257,11 +294,13 @@ void TemplatePage::imageContextMenuRequested(const QPoint &pos)
 
     if ((action = popup.exec(pos)) != 0) {
         if (action == scaledAction) {
-            m_scaled = (m_scaled) ? false : true;
-            templatePreview->setScaled(m_scaled);
+            KMediaFactorySettings::setPreviewScaled(
+                    KMediaFactorySettings::previewScaled() ? false : true);
+            templatePreview->setScaled(KMediaFactorySettings::previewScaled());
+            KMediaFactorySettings::self()->writeConfig();
         } else if (action == saveAction)    {
             KUrl url = KFileDialog::getSaveUrl(KUrl("kfiledialog:///<KMFPreview>"),
-                    i18n("*.png|PNG Graphics file"),
+                    "image/png",
                     kapp->activeWindow());
 
             if (!url.isEmpty() && url.isValid()) {
@@ -271,7 +310,7 @@ void TemplatePage::imageContextMenuRequested(const QPoint &pos)
                 }
             }
         } else if (!templateActions.contains(action))    {
-            m_menu = action->data().toInt();
+            m_menu = MenuIndex(action->data().toInt());
             // previewCheckBox->setChecked(true);
             updatePreview();
         }
